%
% plot_profiles_tsz_indiv
%
% This script plots overlays of temperature and salinity verus depth for the casts in a mods data file.
% The final result is one page of plots for each chosen station
%
%-------------------------------------------------------------------------------
% Set run parameters.
%
%    hydnam     ... MODS format hydrographic data file.
%    pltttl     ... Title for plot
%    fillnan    ... Fill voids in data with NaN's.  [0] no  [1] yes
%    ifprint    ... Toggle for printing plots [n] no  [y] yes
%    ifwrite    ... Toggle for writing  plots [n] no  [y] yes
%-------------------------------------------------------------------------------

fillnan=1;
nrow=3;
ncol=4;

hydnam=input('Enter the file name: ','s');
nchar=length(hydnam)-5;

[header,hinfo,htype,z,t,s]=rhydro(hydnam,fillnan);

plttl = input('Enter the plot title: ','s');
nstation=input('How many stations to plot (>999 for all): ');

ifprint = input('Do you want to print the plots (y/n): ','s');
ifwrite = input('Do you want to write the plots (y/n): ','s');
if(ifwrite=='y')
  pltype  = input('Write plot in Postscript or PNG (ps/pn)  : ','s');
end

plot_num = input('Do you want 1 or 12 plots per page (1/12): ');

if nstation >= 999 
  [nstation npts] = size(t);
  icntr = hinfo(:,3);
else
  icntr=input('Enter the station ids (within brackets): ');
end

switch plot_num
case 1

for i=1:nstation
   dum=find(hinfo(:,3)==icntr(i));
   icntr(i)=dum(1);

%
% temperature and salinity vs depth
%

   figure
   [axT,axS,hlT,hlS] = plotxx(t(i,:)',-z(i,:)',s(i,:)',-z(i,:)');
   grid on
   set(get(axS,'xlabel'),'string','Salinity')
   set(get(axT,'xlabel'),'string','Temperature')
   set(get(axS,'ylabel'),'string','Depth')
   set(get(axT,'ylabel'),'string','Depth')
   suptitle([plttl,' Station ',num2str(hinfo(i,3)),', Lat = ',num2str(hinfo(i,5)),', Lon = ',num2str(hinfo(i,4))])

   orient tall

   if(ifprint=='y')
      print -dpsc -Pmseasclr1
   end
   if(ifwrite=='y')
    if(pltype=='ps')
       outfile=[hydnam(1:nchar),'_tsz_cast',num2str(hinfo(i,3),'%3.3d'),'.ps'];
       print('-dpsc',outfile)
    end
    if(pltype=='pn')
       outfile=[hydnam(1:nchar),'_tsz_cast',num2str(hinfo(i,3),'%3.3d'),'.png'];
       print('-dpng',outfile)
    end
   end

end

case 12

for i=1:nstation
   dum=find(hinfo(:,3)==icntr(i));
   icntr(i)=dum(1);
end

zmin=min(min(-z(icntr(:),:)));
zmax=max(max(-z(icntr(:),:)));
tmin=min(min(t(icntr(:),:)));
tmax=max(max(t(icntr(:),:)));
smin=min(min(s(icntr(:),:)));
smax=max(max(s(icntr(:),:)));

%
% plot the data
%

nsubplot=nrow*ncol;
nfig=floor(nstation/nsubplot);
if(nfig.*nsubplot<nstation),nfig=nfig+1;end

%
nplot=0;
%
for k = 1:nfig
 figure
 nsubplot=0;
 for j=1:nrow
   for i=1:ncol
     nplot=nplot+1;
     nsubplot=nsubplot+1;
     if (nplot <= nstation),
     subplot(nrow,ncol,nsubplot),
     [axT,axS,hlT,hlS] = plotxx(t(icntr(nplot),:)',-z(icntr(nplot),:)',...
                           s(icntr(nplot),:)',-z(icntr(nplot),:)');
     hold on
     grid on
     set(get(axS,'xlabel'),'string','Salinity')
     set(get(axT,'xlabel'),'string','Temperature')
     set(axS,'xlim',[smin smax],'ylim',[zmin zmax],'yticklabel',[])
     set(axT,'xlim',[tmin tmax],'ylim',[zmin zmax])
     text(smin+0.1.*(smax-smin),zmin+0.225.*(zmax-zmin),...
          ['Sta: ',num2str(hinfo(icntr(nplot),3),'%5.0f')]);
     text(smin+0.1.*(smax-smin),zmin+0.15.*(zmax-zmin),...
          ['Lat: ',num2str(hinfo(icntr(nplot),5),4)]);
     text(smin+0.1.*(smax-smin),zmin+0.075.*(zmax-zmin),...
          ['Lon: ',num2str(hinfo(icntr(nplot),4),4)]);

     end 
   end
 end
 orient tall
 suptitle(plttl)
 if(ifprint=='y')
    print -dpsc -Pmseasbw1
 end
 if(ifwrite=='y')
    if(pltype=='ps')
       outfile=[hydnam(1:nchar),'_tsprofile',num2str(k,'%3.3d'),'.ps'];
       print('-dpsc',outfile)
    end
    if(pltype=='pn')
       outfile=[hydnam(1:nchar),'_tsprofile',num2str(k,'%3.3d'),'.png'];
       print('-dpng',outfile)
    end
 end
end

end
